# Generated by Django 3.1.7 on 2023-10-08 05:51

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('body', models.TextField()),
                ('provider', models.CharField(choices=[('kmi', 'Kmi'), ('jak', 'Jak'), ('geez', 'Geez'), ('africastalking', 'Africastalking'), ('none', 'None')], max_length=20)),
                ('sms_id', models.CharField(max_length=100, null=True, unique=True)),
                ('phone', models.CharField(max_length=20)),
                ('success', models.BooleanField(default=True)),
                ('sent_at', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
