# Generated by Django 3.1.7 on 2023-10-08 18:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('smsapp', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='message',
            name='provider',
            field=models.CharField(blank=True, choices=[('kmi', 'Kmi'), ('jak', 'Jak'), ('geez', 'Geez'), ('africastalking', 'Africastalking')], max_length=20, null=True),
        ),
    ]
