# Generated by Django 3.1.7 on 2023-10-12 04:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('smsapp', '0004_auto_20231009_0504'),
    ]

    operations = [
        migrations.AlterField(
            model_name='message',
            name='success',
            field=models.BooleanField(default=False),
        ),
    ]
